function distance_seqs(dist_func, x, y)
    if length(x) > length(y)
        x, y = y, x
    end
    diffs = minimum(Choose(length(x), length(y))) do y_ids
        sum(enumerate(y_ids); init=0) do v
            xid, yid = v
            dist_func(x[xid], y[yid])
        end
    end
    diffs / length(x)
end

function distance(x::MethodInfo, y::MethodInfo)::Float64
    arg_types = if isempty(x.sig.types) || isempty(y.sig.types)
        1
    else
        distance_seqs(x.sig.types, y.sig.types) do x_type, y_type
            x_type == y_type
        end
    end
    arg_names = if isempty(x.args) || isempty(y.args)
        1
    else
        distance_seqs(x.args, y.args) do x_arg, y_arg
            x_arg == y_arg
        end
    end
    kwargs = if isempty(x.kwargs) || isempty(y.kwargs)
        1
    else
        distance_seqs(x.kwargs, y.kwargs) do x_kw, y_kw
            x_kw == y_kw
        end
    end

    mean((arg_types, arg_names, kwargs))
end

function distance(x::Method, y::Method)
    distance(get_method_info(x), get_method_info(y))
end
